<template>
  <v-app light :class="$route.name">
      <v-navigation-drawer
        temporary
        v-model="cart_drawer"
        fixed
        class="cart_drawer"
        width="400"
        right>
        <cart :cart_drawer="cart_drawer" :config="cart"></cart>
      </v-navigation-drawer>
      <v-navigation-drawer
        temporary
        v-model="sidebar"
        width="300"
        absolute>
        <sidebar></sidebar>
      </v-navigation-drawer>
      <main-header 
        @drawer="openDrawer"
        :layout="this"
      ></main-header>
      <mobile-check v-if="!$store.state.customer.mobile && $store.state.customer.id" :layout="this" :noMobile="noMobile" :info="info" :customer="$store.state.customer"></mobile-check>
      <v-content>
          <div class="_content_wrapper container pa-0 column">

            <aside class="sidebar">
              <div class="sticke_sidebar">
                <div class="_card">
                  <div class="_side_menu">
                    <ul>
                      <li>
                        <nuxt-link to="/account/orders">
                          <i class="material-icons">
                            featured_play_list
                          </i>
                          Orders
                        </nuxt-link>
                      </li>
                      <li>
                        <nuxt-link to="/account/addresses">
                          <i class="material-icons">
                            place
                          </i>
                          Addresses
                        </nuxt-link>
                      </li>
                      <li>
                        <nuxt-link to="/account/cards">
                          <i class="material-icons">
                            credit_card
                          </i>
                          Saved Cards
                        </nuxt-link>
                      </li>
                      <li>
                        <nuxt-link to="/account/profile">
                          <i class="material-icons">
                            assignment_ind
                          </i>
                          Profile
                        </nuxt-link>
                      </li>
                      <li>
                        <a :href="$store.state.domain + '?mylogout=true&logout'">
                          <i class="material-icons">power_settings_new</i>
                          Logout
                        </a>
                      </li>
                    </ul>
                  </div>
                </div>
              </div>
            </aside>

            <div class="main_content">
              <nuxt />
            </div>
          </div>
      </v-content>
      <foo :login="login" :customer='customer' :broker="broker"></foo>
      <v-snackbar
        :bottom="true"
        :timeout="getNumber(0)"
        v-model="$store.state.snackbar"
      >
        {{ $store.state.snackbar_text }}
        <v-btn
          color="pink"
          flat
          @click="$store.commit('hideSnackBar')"
        >
          Close
        </v-btn>
      </v-snackbar>
  </v-app>
</template>

<script>
import axios from 'axios';
import Vue from 'vue';
import Cart from '~/components/cart.vue';
import Sidebar from '~/components/sidebarMenu.vue';
import Footer from '~/components/footer.vue';
import Header from '~/components/Header.vue';
import mobileCheck from '~/components/MobileCheck.vue';

Vue.component('cart', Cart);
Vue.component('sidebar', Sidebar);
Vue.component('foo', Footer);
Vue.component('main-header', Header);
Vue.component('mobile-check', mobileCheck);
  export default {
    data () {
      return {
        sidebar: null,
        cart: {
          temporary: true,
          permanent: false,
          fixed: true,
        },
        clipped: true,
        fixed: false,
        items: [
          { icon: 'apps', title: 'Welcome', to: '/' },
          { icon: 'bubble_chart', title: 'Inspire', to: '/inspire' }
        ],
        miniVariant: false,
        right: true,
        rightDrawer: false,
        title: 'Vuetify.js',
        cart: [],
        broker: false,
        customer: false,
        login: false,
        isCustomerLoader: true,
        name: null,
        noMobile: false,
        info: false,
      }
    },
    beforeCreate() {
      // axios.get(this.$store.state.api_domain + '?comp=process&action=checkBroker', {withCredentials:true}).then((res) => {
      //   if (res.data.is_broker == 1 && res.data.id_customer) {
      //     this.$router.push('/broker/dashboard');
      //   } else {
      //     this.isCustomerLoader = false;
      //   }
      //
      //   if (res.data.status == 'error') {
      //     this.$router.push('/account/login');
      //     return;
      //   }
      //   this.name = res.data.firstname + ' ' + res.data.lastname;
      // });
    },
    created () {
      axios.get(this.$store.state.api_domain + '?comp=core', {
        withCredentials: true
      })
      .then((res) => {
        if (res.data.core.cart) {
          this.$store.commit('setCart', res.data.core.cart);
        }
        if (res.data.core.customer) {
          this.$store.commit('setCustomer', res.data.core.customer);
          if (!res.data.core.customer.mobile || res.data.core.customer.mobile.length != 10) {
            this.noMobile = true;
            if (res.data.core.customer.mobile) {
              this.veri.mobile = res.data.core.customer.mobile;
              this.info = true;
            }
          }
        }

        if (
          this.$store.state.customer &&
          this.$store.state.customer.id &&
          this.$store.state.customer.active == 1
        ) {
          if (this.$store.state.customer.is_broker == 1 && this.$store.state.customer.broker_block == 0) {
            this.$router.push('/broker/dashboard');
          }
        } else {
          this.$router.push('/account/login');
        }
      });
    },
    methods: {
      openDrawer () {
        this.sidebar = true;
      },
      getNumber: function (val) {
        return +val;
      },
      deleteProduct: function (id_product, id_product_attribute) {
        var form_data = new FormData();
        form_data.append('id_product', id_product);
        form_data.append('id_product_attribute', id_product_attribute);
        axios.post(this.$store.state.api_domain + '?comp=process&action=deleteProduct', form_data, {
          withCredentials: true
        }).then((res) => {
          if (res.data.status == 'success') {
            this.$store.commit('setCart', res.data.message);
          }
        });
      },
      checkCart: function () {
        var form_data = new FormData;
        form_data.append('test', 'test');
        axios.post(this.$store.state.api_domain + '?comp=process&action=checkCart', form_data, {
          withCredentials: true
        }).then((res) => {
          if (res.data.status == 'success') {
            this.$store.commit('setCart', res.data.message);
          }
        });
      },
      qtyChange: function (data) {
        this.$store.commit('setCartError', false);
        var product = data.product;
        var qty = +data.qty;
        var minimal = +data.product.minimal_quantity;

        if (qty < minimal) {
          this.$store.commit('setCartError', 'Quantity cannot go below minimal ' + minimal);
          this.checkCart();
          var store = this.$store;
          setTimeout(function () {
            store.commit('setCartError', false);
          }, 7000);
          return false;
        }

        var form_data = new FormData();
        form_data.append('id_product', product.id_product);
        form_data.append('id_product_attribute', product.id_product_attribute);
        form_data.append('qty', qty);

        axios.post(this.$store.state.api_domain + '?comp=process&action=qtyChange', form_data, {
          withCredentials: true
        }).then((res) => {
          this.$store.commit('setCart', res.data.message);
        });
      },
    },
    computed: {
        cart_drawer: {
          get() {
            return this.$store.state.cart_drawer
          },
          set(val) {
            this.$store.commit('cartDrawer', val);
          }
        }
    }
  }
</script>
